module.exports = defineTest({
	description: 'handles deconflicting of variables used as defaults in patterns (#2445)'
});
